# -*- coding: utf-8 -*-

"""Console script for surebet."""
import argparse


if __name__ == "__main__":

    parser = argparse.ArgumentParser()

    # define each option with: parser.add_argument

    args = parser.parse_args()  # automatically looks at sys.argv

    # access results with: args.argumentName
